##  Step 1: Install the SAP LeanIX for Jira App
The SAP LeanIX for Jira app is available for download from the Atlassian Marketplace. This means you can find and install the app without leaving your Jira instance.
To install SAP LeanIX for Jira, follow these steps:
  1. In the top navigation bar in Jira, go to Apps > Find new apps.
  2. Enter “SAP LeanIX for Jira” in the search field and choose the app tile.
  3. Choose Get app.
